@@ -41,6 +41,7 @@ def sync(
     *,
     client: httpx.Client,
     quantum_processor_id: str,
+    httpx_request_kwargs: Dict[str, Any] = {},
 ) -> Response[InstructionSetArchitecture]:
     url = "/v1/quantumProcessors/{quantumProcessorId}/instructionSetArchitecture".format(
         quantumProcessorId=quantum_processor_id,
@@ -49,6 +50,7 @@ def sync(
     kwargs = _get_kwargs(
         quantum_processor_id=quantum_processor_id,
     )
+    kwargs.update(httpx_request_kwargs)
     response = client.request(
         "get",
         url,
@@ -62,6 +64,7 @@ def sync_from_dict(
     *,
     client: httpx.Client,
     quantum_processor_id: str,
+    httpx_request_kwargs: Dict[str, Any] = {},
 ) -> Response[InstructionSetArchitecture]:
 
     url = "/v1/quantumProcessors/{quantumProcessorId}/instructionSetArchitecture".format(
@@ -71,13 +74,12 @@ def sync_from_dict(
     kwargs = _get_kwargs(
         quantum_processor_id=quantum_processor_id,
     )
-
+    kwargs.update(httpx_request_kwargs)
     response = client.request(
         "get",
         url,
         **kwargs,
     )
-
     return _build_response(response=response)
 
 
@@ -86,6 +88,7 @@ async def asyncio(
     *,
     client: httpx.AsyncClient,
     quantum_processor_id: str,
+    httpx_request_kwargs: Dict[str, Any] = {},
 ) -> Response[InstructionSetArchitecture]:
     url = "/v1/quantumProcessors/{quantumProcessorId}/instructionSetArchitecture".format(
         quantumProcessorId=quantum_processor_id,
@@ -94,9 +97,12 @@ async def asyncio(
     kwargs = _get_kwargs(
         quantum_processor_id=quantum_processor_id,
     )
-
-    response = await client.request("get", url, **kwargs)
-
+    kwargs.update(httpx_request_kwargs)
+    response = await client.request(
+        "get",
+        url,
+        **kwargs,
+    )
     return _build_response(response=response)
 
 
@@ -105,6 +111,7 @@ async def asyncio_from_dict(
     *,
     client: httpx.AsyncClient,
     quantum_processor_id: str,
+    httpx_request_kwargs: Dict[str, Any] = {},
 ) -> Response[InstructionSetArchitecture]:
 
     url = "/v1/quantumProcessors/{quantumProcessorId}/instructionSetArchitecture".format(
@@ -114,7 +121,10 @@ async def asyncio_from_dict(
     kwargs = _get_kwargs(
         quantum_processor_id=quantum_processor_id,
     )
-
-    response = await client.request("get", url, **kwargs)
-
+    kwargs.update(httpx_request_kwargs)
+    response = await client.request(
+        "get",
+        url,
+        **kwargs,
+    )
     return _build_response(response=response)
