@@ -12,9 +12,30 @@ from qcs_api_client.client._configuration import (
 
 
 class QCSAuthConfiguration(BaseModel):
+    """This configures how ``QCSAuth`` implements its access token refresh mechanism."""
+
     pre: bool = False
+    """Pre-emptively refresh access tokens.
+
+    When set to True, this will check the access token's expiration and refresh
+    when necessary before setting the access token in the outgoing Authorization
+    header.
+    """
+
     post: bool = True
+    """Refresh access tokens based on response status code.
+
+    When set to True, this will check responses for the status codes configured
+    in ``post_refresh_statuses``. On match, ``QCSAuth`` will refresh the access token
+    and retry the request.
+    """
+
     post_refresh_statuses: Set[int] = Field(default_factory=lambda: {HTTPStatus.UNAUTHORIZED, HTTPStatus.FORBIDDEN})
+    """Response status codes which indicates a possible expired token payload.
+
+    This contains a set of HTTP status codes which ``QCSAuth`` will check on
+    responses when `post` is set to True.
+    """
 
 
 class QCSAuthRefreshError(Exception):
@@ -25,6 +46,17 @@ class QCSAuthRefreshError(Exception):
 
 
 class QCSAuth(httpx.Auth):
+    """Implements ``httpx.Auth`` ``sync_auth_flow`` and ``async_auth_flow``.
+
+    If the ``QCSClientConfiguration`` that initializes this class has a valid
+    ``TokenPayload`` on ``QCSClientConfiguration.credentials``, it will set the
+    a refreshed access token as a Bearer token on the Authorization header
+    of outgoing requests.
+
+    Access tokens are refreshed via OAuth2 refresh mechanism as indicated
+    by ``QCSAuthConfiguration``.
+    """
+
     def __init__(self, client_configuration: QCSClientConfiguration, auth_configuration: QCSAuthConfiguration = None):
         self._client_configuration = client_configuration
         self._sync_lock = threading.RLock()
@@ -47,6 +79,10 @@ class QCSAuth(httpx.Auth):
             )
 
     def sync_auth_flow(self, request):
+        if self._client_configuration.credentials.token_payload is None:
+            yield request
+            return
+
         if self._auth_configuration.pre and self._client_configuration.credentials.token_payload.should_refresh():
             self.sync_refresh_token()
 
@@ -74,6 +110,10 @@ class QCSAuth(httpx.Auth):
             )
 
     async def async_auth_flow(self, request):
+        if self._client_configuration.credentials.token_payload is None:
+            yield request
+            return
+
         if self._auth_configuration.pre and self._client_configuration.credentials.token_payload.should_refresh():
             await self.async_refresh_token()
 
