@@ -15,6 +15,7 @@ class Error:
     message: str
     request_id: str
     validation_errors: Union[Unset, List[ValidationError]] = UNSET
+    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)
 
     def to_dict(self, pick_by_predicate: Optional[Callable[[Any], bool]] = is_not_none) -> Dict[str, Any]:
         code = self.code
@@ -28,38 +29,62 @@ class Error:
 
                 validation_errors.append(validation_errors_item)
 
-        dct = {
-            k: v
-            for k, v in {
+        field_dict: Dict[str, Any] = {}
+        field_dict.update(self.additional_properties)
+        field_dict.update(
+            {
                 "code": code,
                 "message": message,
                 "requestId": request_id,
-                "validationErrors": validation_errors,
-            }.items()
-            if v != UNSET
-        }
+            }
+        )
+        if validation_errors is not UNSET:
+            field_dict["validationErrors"] = validation_errors
+
+        field_dict = {k: v for k, v in field_dict.items() if v != UNSET}
         if pick_by_predicate is not None:
-            dct = {k: v for k, v in dct.items() if pick_by_predicate(v)}
-        return dct
+            field_dict = {k: v for k, v in field_dict.items() if pick_by_predicate(v)}
+
+        return field_dict
 
     @staticmethod
-    def from_dict(d: Dict[str, Any]) -> "Error":
-        code = d["code"]
+    def from_dict(src_dict: Dict[str, Any]) -> "Error":
+        d = src_dict.copy()
+        code = d.pop("code")
 
-        message = d["message"]
+        message = d.pop("message")
 
-        request_id = d["requestId"]
+        request_id = d.pop("requestId")
 
         validation_errors = []
-        _validation_errors = d.get("validationErrors")
+        _validation_errors = d.pop("validationErrors", UNSET)
         for validation_errors_item_data in _validation_errors or []:
             validation_errors_item = ValidationError.from_dict(validation_errors_item_data)
 
             validation_errors.append(validation_errors_item)
 
-        return Error(
+        error = Error(
             code=code,
             message=message,
             request_id=request_id,
             validation_errors=validation_errors,
         )
+
+        error.additional_properties = d
+        return error
+
+    @property
+    def additional_keys(self) -> List[str]:
+        return list(self.additional_properties.keys())
+
+    def __getitem__(self, key: str) -> Any:
+        return self.additional_properties[key]
+
+    def __setitem__(self, key: str, value: Any) -> None:
+        self.additional_properties[key] = value
+
+    def __delitem__(self, key: str) -> None:
+        del self.additional_properties[key]
+
+    def __contains__(self, key: str) -> bool:
+        return key in self.additional_properties
